# bestia
***
Bestia is a library of functions and classes designed to help you build dynamic command-line applications on Linux / Darwin systems.

## modules

* connect
* iter
* misc
* output

## functions

### connect

### iter

### misc

### output
